@@ -1045,7 +1045,7 @@ int MADB_CharToSQLNumeric(char *buffer, MADB_Desc *Ard, MADB_DescRecord *ArdReco
       
       memcpy(digits + digits_count, dot + 1, digits_significant);
       digits_count+= digits_significant;
-
+      number->scale= (SQLSCHAR)digits_significant;
     } else 
     {
       char *start= p;
@@ -1292,3 +1292,18 @@ BOOL MADB_IsIntType(SQLSMALLINT ConciseType)
   return FALSE;
 }
 
+
+void MADB_InstallStmt(MADB_Stmt *Stmt)
+{
+  Stmt->stmt= Stmt->MultiStmts[Stmt->MultiStmtNr];
+
+  if (mysql_stmt_field_count(Stmt->stmt) == 0)
+  {
+    Stmt->AffectedRows= mysql_stmt_affected_rows(Stmt->stmt);
+  }
+  else
+  {
+    MADB_StmtResetResultStructures(Stmt);
+    MADB_DescSetIrdMetadata(Stmt, mysql_fetch_fields(FetchMetadata(Stmt)), mysql_stmt_field_count(Stmt->stmt));
+  }
+}
\ No newline at end of file
