@@ -98,7 +98,7 @@ size_t MADB_ConvertNumericToChar(SQL_NUMERIC_STRUCT *Numeric, char *Buffer, int
   if (Numeric->scale > 0)
   {
     char tmp[38];
-    _snprintf(tmp, 38, "%%%d.%df", Numeric->precision, Numeric->scale);
+    _snprintf(tmp, 38, "%%.%df", Numeric->scale);
     _snprintf(Buffer, 38, tmp, Numerator / pow(10, Scale));
   }
   else
@@ -578,7 +578,7 @@ SQLRETURN MADB_ConvertC2Sql(MADB_Stmt *Stmt, MADB_DescRecord *CRec, void* DataPt
     MaBind->buffer_type=   0;
     MaBind->is_unsigned=   0;
 
-    *LengthPtr= Length;
+    *LengthPtr= (unsigned long)Length;
     MaBind->buffer_type= MADB_GetMaDBTypeAndLength(CRec->ConciseType,
       &MaBind->is_unsigned, &MaBind->buffer_length);
 
